@@ -177,7 +177,6 @@ D.UPM<- Vectorize(D.UPM,vectorize.args = c('target.x','target.y'))
 #'
 #'
 #' This function generates a co-partial moment matrix for the specified co-partial moment.
-#' @param Co.PM options: ("Co.LPM", "Co.UPM", "D.LPM", "D.UPM"); partial moment quadrant to generate matrix of.  \code{NULL} (default) returns all partial moment matrices.
 #' @param LPM.degree integer; Degree for \code{variable} below \code{target} deviations.  \code{(degree = 0)} is frequency, \code{(degree = 1)} is area.
 #' @param UPM.degree integer; Degree for \code{variable} above \code{target} deviations.  \code{(degree = 0)} is frequency, \code{(degree = 1)} is area.
 #' @param target numeric; Typically the mean of Variable X for classical statistics equivalences, but does not have to be. (Vectorized)  \code{(target = "mean")} will set the target as the mean of every variable.
@@ -193,79 +192,73 @@ D.UPM<- Vectorize(D.UPM,vectorize.args = c('target.x','target.y'))
 #' set.seed(123)
 #' x<-rnorm(100); y<-rnorm(100); z<-rnorm(100)
 #' A<-cbind(x,y,z)
-#' PM.matrix(LPM.degree=0, UPM.degree=0, target="mean", variable=A)
+#' PM.matrix(LPM.degree=1, UPM.degree=1, target="mean", variable=A)
 #'
-#' ## Calling Multiple Partial Moment Quadrants
-#' PM.matrix(c("Co.LPM","Co.UPM"), LPM.degree=0, UPM.degree=0, target="mean", variable=A)
+#' ## Calling Individual Partial Moment Quadrants
+#' cov.mtx=PM.matrix(LPM.degree=1, UPM.degree=1, target="mean", variable=A)
+#' cov.mtx$cupm
+#'
+#' ## Full covariance matrix
+#' cov.mtx$matrix
 #' @export
 
 
-PM.matrix <- function(Co.PM=NULL,LPM.degree,UPM.degree,target,variable,pop.adj=FALSE){
-  if(is.null(Co.PM)){Co.PM=c("Co.LPM", "Co.UPM", "D.LPM","D.UPM")}
+PM.matrix <- function(LPM.degree,UPM.degree,target,variable,pop.adj=FALSE){
+
   n= ncol(variable)
   if(is.null(n)){stop("supply a matrix-like 'variable'")}
-  if("Co.LPM"%in%Co.PM){
+
     clpms=list()
     for(i in 1:n){
       if(is.numeric(target)){
-      clpms[[i]]=sapply(i:n, function(b) Co.LPM(x=variable[,i],y=variable[,b],degree.x = LPM.degree,degree.y = LPM.degree,target.x = target,target.y=target))} else {
-      clpms[[i]]=sapply(i:n, function(b) Co.LPM(x=variable[,i],y=variable[,b],degree.x = LPM.degree,degree.y = LPM.degree,target.x = mean(variable[,i]),target.y=mean(variable[,b])))
+      clpms[[i]]=sapply(1:n, function(b) Co.LPM(x=variable[,i],y=variable[,b],degree.x = LPM.degree,degree.y = LPM.degree,target.x = target,target.y=target))} else {
+      clpms[[i]]=sapply(1:n, function(b) Co.LPM(x=variable[,i],y=variable[,b],degree.x = LPM.degree,degree.y = LPM.degree,target.x = mean(variable[,i]),target.y=mean(variable[,b])))
       }
     }
-    clpm.matrix <- matrix(, n, n)
-    clpm.matrix[lower.tri(clpm.matrix, diag=TRUE)] <- unlist(clpms)
-    clpm.matrix = pmax(clpm.matrix, t(clpm.matrix), na.rm=TRUE)
+    clpm.matrix <- matrix(unlist(clpms), n, n)
+
     colnames(clpm.matrix) = colnames(variable);rownames(clpm.matrix) = colnames(variable)
-  } else {clpm.matrix=matrix(0, n, n)}
+
 
-  if("Co.UPM"%in%Co.PM){
     cupms=list()
     for(i in 1:n){
       if(is.numeric(target)){
-        cupms[[i]]=sapply(i:n, function(b) Co.UPM(x=variable[,i],y=variable[,b],degree.x = UPM.degree,degree.y = UPM.degree,target.x = target,target.y=target))} else {
-        cupms[[i]]=sapply(i:n, function(b) Co.UPM(x=variable[,i],y=variable[,b],degree.x = UPM.degree,degree.y = UPM.degree,target.x = mean(variable[,i]),target.y=mean(variable[,b])))
+        cupms[[i]]=sapply(1:n, function(b) Co.UPM(x=variable[,i],y=variable[,b],degree.x = UPM.degree,degree.y = UPM.degree,target.x = target,target.y=target))} else {
+        cupms[[i]]=sapply(1:n, function(b) Co.UPM(x=variable[,i],y=variable[,b],degree.x = UPM.degree,degree.y = UPM.degree,target.x = mean(variable[,i]),target.y=mean(variable[,b])))
         }
     }
-    cupm.matrix <- matrix(, n, n)
-    cupm.matrix[lower.tri(cupm.matrix, diag=TRUE)] <- unlist(cupms)
-    cupm.matrix = pmax(cupm.matrix, t(cupm.matrix), na.rm=TRUE)
+    cupm.matrix <- matrix(unlist(cupms), n, n)
     colnames(cupm.matrix) = colnames(variable);rownames(cupm.matrix) = colnames(variable)
-  } else {cupm.matrix=matrix(0, n, n)}
 
-  if("D.LPM"%in%Co.PM){
-    dlpms1=list();dlpms2=list()
-    for(i in 1:(n-1)){
+
+
+    dlpms=list()
+    for(i in 1:(n)){
       if(is.numeric(target)){
-        dlpms1[[i]]=sapply((i+1):n, function(b) D.LPM(x=variable[,i],y=variable[,b],degree.x = UPM.degree,degree.y = LPM.degree,target.x = target,target.y=target))
-        dlpms2[[i]]=sapply((i+1):n, function(b) D.LPM(y=variable[,i],x=variable[,b],degree.x = UPM.degree,degree.y = LPM.degree,target.y = target,target.x=target))
+        dlpms[[i]]=sapply(1:n, function(b) D.LPM(x=variable[,i],y=variable[,b],degree.x = UPM.degree,degree.y = LPM.degree,target.x = target,target.y=target))
+
         } else {
-        dlpms1[[i]]=sapply((i+1):n, function(b) D.LPM(x=variable[,i],y=variable[,b],degree.x = UPM.degree,degree.y = LPM.degree,target.x = mean(variable[,i]),target.y=mean(variable[,b])))
-        dlpms2[[i]]=sapply((i+1):n, function(b) D.LPM(y=variable[,i],x=variable[,b],degree.x = UPM.degree,degree.y = LPM.degree,target.y = mean(variable[,i]),target.x=mean(variable[,b])))
+        dlpms[[i]]=sapply(1:n, function(b) D.LPM(x=variable[,i],y=variable[,b],degree.x = UPM.degree,degree.y = LPM.degree,target.x = mean(variable[,i]),target.y=mean(variable[,b])))
         }
     }
-    dlpm.matrix <- matrix(, n, n)
-    dlpm.matrix[lower.tri(dlpm.matrix, diag=FALSE)] <- unlist(dlpms1)
-    dlpm.matrix[upper.tri(dlpm.matrix, diag=FALSE)] <- unlist(dlpms2)
+    dlpm.matrix <- matrix(unlist(dlpms), n, n)
     diag(dlpm.matrix) <- 0
     colnames(dlpm.matrix) = colnames(variable);rownames(dlpm.matrix) = colnames(variable)
-  } else {dlpm.matrix=matrix(0, n, n)}
-  if("D.UPM"%in%Co.PM){
-    dupms1=list();dupms2=list()
-    for(i in 1:(n-1)){
+
+
+    dupms=list()
+    for(i in 1:(n)){
       if(is.numeric(target)){
-        dupms1[[i]]=sapply((i+1):n, function(b) D.UPM(x=variable[,i],y=variable[,b],degree.x = LPM.degree,degree.y = UPM.degree,target.x = target,target.y=target))
-        dupms2[[i]]=sapply((i+1):n, function(b) D.UPM(y=variable[,i],x=variable[,b],degree.x = LPM.degree,degree.y = UPM.degree,target.y = target,target.x=target))
+        dupms[[i]]=sapply(1:n, function(b) D.UPM(x=variable[,i],y=variable[,b],degree.x = LPM.degree,degree.y = UPM.degree,target.x = target,target.y=target))
       } else {
-        dupms1[[i]]=sapply((i+1):n, function(b) D.UPM(x=variable[,i],y=variable[,b],degree.x = LPM.degree,degree.y = UPM.degree,target.x = mean(variable[,i]),target.y=mean(variable[,b])))
-        dupms2[[i]]=sapply((i+1):n, function(b) D.UPM(y=variable[,i],x=variable[,b],degree.x = LPM.degree,degree.y = UPM.degree,target.y = mean(variable[,i]),target.x=mean(variable[,b])))
+        dupms[[i]]=sapply(1:n, function(b) D.UPM(x=variable[,i],y=variable[,b],degree.x = LPM.degree,degree.y = UPM.degree,target.x = mean(variable[,i]),target.y=mean(variable[,b])))
       }
     }
-    dupm.matrix <- matrix(0, n, n)
-    dupm.matrix[lower.tri(dupm.matrix, diag=FALSE)] <- unlist(dupms1)
-    dupm.matrix[upper.tri(dupm.matrix, diag=FALSE)] <- unlist(dupms2)
+
+    dupm.matrix <- matrix(unlist(dupms), n, n)
     diag(dupm.matrix) <- 0
     colnames(dupm.matrix) = colnames(variable);rownames(dupm.matrix) = colnames(variable)
-  } else {dupm.matrix=matrix(0, n, n)}
+
 
   if(pop.adj){
     adjustment=(length(variable[,1])/(length(variable[,1])-1))
@@ -275,7 +268,11 @@ PM.matrix <- function(Co.PM=NULL,LPM.degree,UPM.degree,target,variable,pop.adj=F
     dupm.matrix=dupm.matrix*adjustment
   }
 
-  return(list(clpm=clpm.matrix,cupm=cupm.matrix,dlpm=dlpm.matrix,dupm=dupm.matrix))
+  components=list(clpm=clpm.matrix,cupm=cupm.matrix,dlpm=dlpm.matrix,dupm=dupm.matrix)
+
+  cov.matrix=components$clpm+components$cupm-components$dlpm-components$dupm
+
+  return(list(clpm=components$clpm,cupm=components$cupm,dlpm=components$dlpm,dupm=components$dupm,matrix=cov.matrix))
 }
 
 
