@@ -20,55 +20,86 @@
 
 NNS.seas <- function(variable,plot=TRUE){
 
-  output <- vector("numeric", length(variable)/4)
-  instances <- vector("numeric", length(variable)/4)
+  variable_1=variable[1:(length(variable)-1)]
+  variable_2=variable_1[1:(length(variable_1)-1)]
+
+
+  output=numeric(); output_1=numeric(); output_2=numeric()
+  instances=numeric(); instances_1=numeric(); instances_2=numeric()
 
   if(mean(variable)!=0){
-  var.cov<- abs(sd(variable)/mean(variable))}
+  var.cov=abs(sd(variable)/mean(variable))}
   else{
-    var.cov<- Inf
+    var.cov=Inf
   }
 
   for (i in 1:(length(variable)/4)){
-      if (abs(sd(variable[seq(length(variable),1,-i)])/mean(variable[seq(length(variable),1,-i)])) < var.cov){
+    reverse.var=variable[seq(length(variable),1,-i)]
+    reverse.var_1=variable_1[seq(length(variable_1),1,-i)]
+    reverse.var_2=variable_2[seq(length(variable_2),1,-i)]
 
+    test=abs(sd(reverse.var)/mean(reverse.var))
+    test_1=abs(sd(reverse.var_1)/mean(reverse.var_1))
+    test_2=abs(sd(reverse.var_2)/mean(reverse.var_2))
+      if (test <= var.cov){
           instances[i] <- i
-
-          output[i]<- (abs(sd(variable[seq(length(variable),1,-i)])/mean(variable[seq(length(variable),1,-i)])))
+          output[i]<- test
       } else {
             instances[i] <- 0
             output[i]<- 0
-        }
+      }
+
+    if (test_1 <= var.cov){
+      instances_1[i] <- i
+      output_1[i]<- test_1
+    } else {
+      instances_1[i] <- 0
+      output_1[i]<- 0
+    }
+
+    if (test_2 <= var.cov){
+      instances_2[i] <- i
+      output_2[i]<- test_2
+    } else {
+      instances_2[i] <- 0
+      output_2[i]<- 0
+    }
   }
 
+  ref.output=cbind(instances,output,output_1,output_2,output*output_1*output_2>0)
+  output=rowMeans(ref.output[,2:4])*ref.output[,5]
 
-  if(length(instances[instances>0])>0){
+  instances=ref.output[,1]*ref.output[,5]
 
-      n<- rep(var.cov,length(instances[instances>0]))
+  index=which(instances>0&output>0)
 
-      M<- data.table("Period"=instances[instances>0],"Coefficient.of.Variance"=output[output>0],"Variable.Coefficient.of.Variance"=n,key = "Coefficient.of.Variance")
+  insts=sum(instances>0)>0
 
-      M<- M[is.finite(rowSums(M))]
+  if(insts){
+
+      n=rep(var.cov,length(instances[index]))
+
+      M=data.table("Period"=instances[index],"Coefficient.of.Variance"=output[index],"Variable.Coefficient.of.Variance"=n,key = "Coefficient.of.Variance")
 
     } else {M="No Seasonality Detected"}
 
 
-    if(sum(instances[instances>0])>0){
-      if(plot==T){
-  plot(instances[instances>0],output[output>0],
+    if(insts){
+      if(plot){
+  plot(instances[index],output[index],
          xlab="Period", ylab="Coefficient of Variance", main = "Seasonality Test",
          ylim = c(0,2*abs(sd(variable)/mean(variable))))
 
     points(M[1,Period],M[1,Coefficient.of.Variance],pch=19,col='red')
 
     abline(h=abs(sd(variable)/mean(variable)), col="red",lty=5)
-    text(mean(instances[instances>0]),abs(sd(variable)/mean(variable)),pos=3,
+    text(mean(instances[index]),abs(sd(variable)/mean(variable)),pos=3,
          "Variable Coefficient of Variance",col='red')}
 
   }
 
 
-    if(length(instances[instances>0])>0){
+    if(insts){
       return(list("all.periods"=M,"best.period"=M[1,Period]))
     }
     else { return(M) }
